==> download.php?FileName=terralib-5.2.0.zip: src/terralib/qt/plugins/wtss/Plugin.cpp <==
/*
  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

  This file is part of the TerraLib - a Framework for building GIS enabled
  applications.

  TerraLib is free software: you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation, either version 3 of the License,
  or (at your option) any later version.

  TerraLib is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with TerraLib. See COPYING. If not, write to
  TerraLib Team at <terralib-team@terralib.org>.
*/


/*!
  \file terralib/qt/plugins/wtss/plugin.cpp

  \brief Add a plugin interface for dynamic loading of the Web Time Series Data
  Service plugin.

  \author Matheus Cavassan Zaglia
 */

// Terralib
#include "../../af/ApplicationController.h"
#include "../../af/Utils.h"
#include "../../af/events/ApplicationEvents.h"
#include "../../af/events/MapEvents.h"
#include "../../af/BaseApplication.h"
#include "../../widgets/canvas/MapDisplay.h"

// QT
#include <QApplication>

// wtss
#include "Plugin.h"
#include "ServerManager.h"
#include "WtssDialog.h"

te::qt::plugins::wtss::Plugin::Plugin(const te::core::PluginInfo& pluginInfo)
    : QObject(), te::core::CppPlugin(pluginInfo), m_wtssDlg(0)
{
  te::qt::af::AppCtrlSingleton::getInstance().addListener(this,
                                                          te::qt::af::SENDER);
}

te::qt::plugins::wtss::Plugin::~Plugin() {}

void te::qt::plugins::wtss::Plugin::startup()
{
  if(m_initialized)
      return;

  m_initialized = true;

  {
    m_menu = te::qt::af::AppCtrlSingleton::getInstance().getMenu("Plugins");

    m_wtssAction = new QAction(this);
    m_wtssAction->setText("Web Time Series Services");
    m_wtssAction->setIcon(QIcon::fromTheme("chart-time-series"));
    m_wtssAction->setObjectName("Tools.WTSS");

    m_menu->addAction(m_wtssAction);

    m_timeSeriesAction = new QAction(this);
    m_timeSeriesAction->setText("Query Time Series...");
    m_timeSeriesAction->setObjectName("Tools.WTSS.Query Time Series");
    m_timeSeriesAction->setCheckable(true);
    m_timeSeriesAction->setIcon(QIcon::fromTheme("chart-time-series"));
    m_timeSeriesAction->setEnabled(true);

    m_wtssToolBar = new QToolBar("WTSS Toolbar");
    m_wtssToolBar->addAction(m_timeSeriesAction);
    m_wtssToolBar->setEnabled(true);

    registerActions();

   QActionGroup* m_wtssTool =
        te::qt::af::AppCtrlSingleton::getInstance().findActionGroup(
            "Map.ToolsGroup");
    assert(m_wtssTool);

    m_wtssTool->addAction(m_timeSeriesAction);
  }
}

void te::qt::plugins::wtss::Plugin::shutdown()
{
  if(!m_initialized)
      return;

  m_initialized = false;

  delete m_wtssAction;
  delete m_timeSeriesAction;
  delete m_wtssToolBar;
  delete m_wtssDlg;

  te::qt::af::AppCtrlSingleton::getInstance().removeToolBar("WTSS Toolbar");

  te::qt::af::AppCtrlSingleton::getInstance().removeListener(this);
}

void te::qt::plugins::wtss::Plugin::registerActions()
{
  connect(m_wtssAction, SIGNAL(triggered(bool)), this,
          SLOT(onActionActivated(bool)));

  connect(m_timeSeriesAction, SIGNAL(toggled(bool)), this,
          SLOT(onActionQueryToggled()));
}

void te::qt::plugins::wtss::Plugin::unregisterActions() {}

te::qt::widgets::MapDisplay* te::qt::plugins::wtss::Plugin::getMapDisplay()
{
  te::qt::af::BaseApplication* baseApplication =
      dynamic_cast<te::qt::af::BaseApplication*>(
          te::qt::af::AppCtrlSingleton::getInstance().getMainWindow());

  return baseApplication->getMapDisplay();
}

void te::qt::plugins::wtss::Plugin::onActionActivated(bool)
{
  te::qt::af::evt::NewActionsAvailable e;
  e.m_toolbar = m_wtssToolBar;
  e.m_category = "WTSSToolbar";

  emit triggered(&e);
}

void te::qt::plugins::wtss::Plugin::onActionQueryToggled()
{
  if(!m_wtssDlg)
  {
    m_wtssDlg = new te::qt::plugins::wtss::WtssDialog(
                te::qt::af::AppCtrlSingleton::getInstance().getMainWindow());
  }

  m_wtssDlg->setMapDisplay(getMapDisplay());

  m_wtssDlg->onPointPickerToggled(true);
}

void te::qt::plugins::wtss::Plugin::onClose()
{
  if(m_wtssDlg)
  {
    delete m_wtssDlg;
    m_wtssDlg = 0;
  }
}

TERRALIB_PLUGIN_CALL_BACK_IMPL(te::qt::plugins::wtss::Plugin)

==> download.php?FileName=terralib-5.3.2.zip: src/terralib/qt/plugins/wtss/Plugin.cpp <==
/*
  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

  This file is part of the TerraLib - a Framework for building GIS enabled
  applications.

  TerraLib is free software: you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation, either version 3 of the License,
  or (at your option) any later version.

  TerraLib is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with TerraLib. See COPYING. If not, write to
  TerraLib Team at <terralib-team@terralib.org>.
*/


/*!
  \file terralib/qt/plugins/wtss/plugin.cpp

  \brief Add a plugin interface for dynamic loading of the Web Time Series Data
  Service plugin.

  \author Matheus Cavassan Zaglia
 */

// Terralib
#include "../../af/ApplicationController.h"
#include "../../af/Utils.h"
#include "../../af/events/ApplicationEvents.h"
#include "../../af/events/MapEvents.h"
#include "../../af/BaseApplication.h"
#include "../../widgets/canvas/MapDisplay.h"

// QT
#include <QApplication>

// wtss
#include "Plugin.h"
#include "ServerManager.h"
#include "WtssDialog.h"

te::qt::plugins::wtss::Plugin::Plugin(const te::core::PluginInfo& pluginInfo)
    : QObject(), te::core::CppPlugin(pluginInfo)
{
  te::qt::af::AppCtrlSingleton::getInstance().addListener(this,
                                                          te::qt::af::SENDER);
}

te::qt::plugins::wtss::Plugin::~Plugin() {}

void te::qt::plugins::wtss::Plugin::startup()
{
  if(m_initialized)
      return;

  m_initialized = true;

  {
    m_menu = te::qt::af::AppCtrlSingleton::getInstance().getMenu("Plugins");

    m_wtssAction = new QAction(this);
    m_wtssAction->setText("Web Time Series Services");
    m_wtssAction->setIcon(QIcon::fromTheme("chart-time-series"));
    m_wtssAction->setObjectName("Tools.WTSS");

    m_menu->addAction(m_wtssAction);

    m_timeSeriesAction = new QAction(this);
    m_timeSeriesAction->setText("Query Time Series...");
    m_timeSeriesAction->setObjectName("Tools.WTSS.Query Time Series");
    m_timeSeriesAction->setCheckable(true);
    m_timeSeriesAction->setIcon(QIcon::fromTheme("chart-time-series"));
    m_timeSeriesAction->setEnabled(true);

    m_wtssToolBar = new QToolBar("WTSS Toolbar");
    m_wtssToolBar->addAction(m_timeSeriesAction);
    m_wtssToolBar->setEnabled(true);

    registerActions();
  }
}

void te::qt::plugins::wtss::Plugin::shutdown()
{
  if(!m_initialized)
      return;

  m_initialized = false;

  delete m_wtssAction;
  delete m_timeSeriesAction;
  delete m_wtssToolBar;

  te::qt::af::AppCtrlSingleton::getInstance().removeToolBar("WTSS Toolbar");

  te::qt::af::AppCtrlSingleton::getInstance().removeListener(this);
}

void te::qt::plugins::wtss::Plugin::registerActions()
{
  connect(m_wtssAction, SIGNAL(triggered(bool)), this,
          SLOT(onActionActivated(bool)));

  connect(m_timeSeriesAction, SIGNAL(toggled(bool)), this,
          SLOT(onActionQueryToggled()));
}

void te::qt::plugins::wtss::Plugin::unregisterActions() {}

void te::qt::plugins::wtss::Plugin::onActionActivated(bool)
{
  te::qt::af::evt::NewActionsAvailable e;
  e.m_toolbar = m_wtssToolBar;
  e.m_category = "WTSSToolbar";

  emit triggered(&e);
}

void te::qt::plugins::wtss::Plugin::onActionQueryToggled()
{
  if(!m_timeSeriesAction->isChecked())
  {
    m_timeSeriesAction->blockSignals(true);
    m_timeSeriesAction->setChecked(true);
    m_timeSeriesAction->blockSignals(false);
    return;
  }

  m_wtssDlg.reset(new te::qt::plugins::wtss::WtssDialog(
                te::qt::af::AppCtrlSingleton::getInstance().getMainWindow()));

  te::qt::af::BaseApplication* baseApplication =
      dynamic_cast<te::qt::af::BaseApplication*>(
          te::qt::af::AppCtrlSingleton::getInstance().getMainWindow());

  connect(m_wtssDlg.get(), SIGNAL(close()), this, SLOT(onCloseTool()));

  QActionGroup* mapEditionTools = te::qt::af::AppCtrlSingleton::getInstance().findActionGroup("Map.ToolsGroup");
  assert(mapEditionTools);

  m_wtssDlg->setActionGroup(mapEditionTools);

  m_wtssDlg->setMapDisplay(baseApplication->getMapDisplay());

  m_wtssDlg->setModal(false);

  m_wtssDlg->show();
}

void te::qt::plugins::wtss::Plugin::onCloseTool()
{
  m_timeSeriesAction->blockSignals(true);
  m_timeSeriesAction->setChecked(false);
  m_timeSeriesAction->blockSignals(false);

  m_wtssDlg.reset(0);
}

TERRALIB_PLUGIN_CALL_BACK_IMPL(te::qt::plugins::wtss::Plugin)
